@@ -29,6 +29,7 @@ from .supereffectmodule import normalize_audio
 from .supereffectmodule import dynamic_overlay
 from .supereffectmodule import combine_audio
 from .supereffectmodule import calc_pan
+from .supereffectmodule import write_script
 
 from .loadingmodule import load_mp3
 from .loadingmodule import load_wav
@@ -47,7 +48,7 @@ def main():
     al = len(args)
     
     if(al == 0):
-        print "Welcome to Python CLI a tool to replace DAW using DSP "
+        print ("Welcome to Python CLI a tool to replace DAW using DSP ")
         togller =False
     
     if(al > 0):
@@ -68,7 +69,7 @@ def main():
         if( i==0 ):
             if(arg == "loadwav"):
                 load_wav(args)
-            elif (arg == "loadmp"):
+            elif (arg == "loadmp3"):
                 load_mp3(args)
             elif (arg == "gain"):
                 posgain(args)
@@ -112,6 +113,8 @@ def main():
                 change_bit_rate(args)
             elif ( arg == "getmax" ):
                 get_max(args)
+            elif (arg == "script" ):
+                write_script(args)
             else:
                 print ("Command is not found or incorrect please try again ")
         print('input argument :: {}'.format(arg))
