@@ -4,7 +4,7 @@ import pydub
 import glob
 from pydub import AudioSegment
 # import pyaudio
-import numpy as np
+# import numpy as np
 cwd = os.getcwd()
 
 
@@ -28,27 +28,45 @@ def convert_all_wav(cmnd):
             AudioSegment.from_file(video).export(wav_filename, format='wav')
     
 def load_any(cmnd):
-    print "Loading file and converting it to wav "
+    
+    print ("Loading file and converting it to wav ")
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     file_type = input_name[-3:]
     print(file_type)
     version = AudioSegment.from_file(input_name, str(file_type) )
+    print("The returned type",type(version))
     return version
     # version.export("temporary.wav",format="wav")
     #remember to delete file after operation is called
     #os.remove(cwd +'/temporary.wav')
     # send flag to all functions whether to perform a delete or not 
 
+def load_txt(cmnd, counter):
+    print ("Loading file and converting it to wav ")
+    print(cwd)
+    #text file name
+    text_file = cmnd[1]
+    i_file=open(text_file,'r')
+    for i in range(6):
+        i_file.readline() 
+        items=i_file.readline().split()
+    #input name deducted from file
+    input_name= items[counter]
+    print(input_name)
+    file_type = input_name[-3:]
+    print(file_type)
+    version = AudioSegment.from_file(input_name, str(file_type) )
+    print("The returned type",type(version))
+    return version
+
 
 def change_bit_rate(cmnd):
-    print "Loading file and converting it to wav "
+    print ("Loading file and converting it to wav ")
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     file_type = input_name[-3:]
@@ -57,20 +75,19 @@ def change_bit_rate(cmnd):
     version.export('bitrate'+'.'+file_type,format=file_type , bitrate= val+'k')
 
 def export_with_tags(cmnd):
-    print "Loading file"
+    print ("Loading file")
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     sound = AudioSegment.from_mp3(input_name)
     sound.export("mashup.mp3", format="mp3", tags={'artist': 'Various artists', 'album': 'Best of 2011', 'comments': 'This album is awesome!'})
 
 def load_wav(cmnd):
-    print "Loading wave"
+    print ("Loading wave") 
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
+    
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     # initialize portaudio
@@ -93,7 +110,6 @@ def load_mp3(cmnd):
     print "Loading mp3"
     print(cwd)
     text_to_file = cmnd[1]
-    CHUNKSIZE = 1024 # fixed chunk size
     input_name= cwd +'/'+ text_to_file
     print(input_name)
     
